@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 
 from rest_framework import status
 from rest_framework.response import Response
@@ -7,7 +6,7 @@ from rest_framework_extensions.settings import extensions_api_settings
 from rest_framework_extensions import utils
 
 
-class BulkOperationBaseMixin(object):
+class BulkOperationBaseMixin:
     def is_object_operation(self):
         return bool(self.get_object_lookup_value())
 
@@ -16,7 +15,8 @@ class BulkOperationBaseMixin(object):
 
     def is_valid_bulk_operation(self):
         if extensions_api_settings.DEFAULT_BULK_OPERATION_HEADER_NAME:
-            header_name = utils.prepare_header_name(extensions_api_settings.DEFAULT_BULK_OPERATION_HEADER_NAME)
+            header_name = utils.prepare_header_name(
+                extensions_api_settings.DEFAULT_BULK_OPERATION_HEADER_NAME)
             return bool(self.request.META.get(header_name, None)), {
                 'detail': 'Header \'{0}\' should be provided for bulk operation.'.format(
                     extensions_api_settings.DEFAULT_BULK_OPERATION_HEADER_NAME
@@ -29,7 +29,7 @@ class BulkOperationBaseMixin(object):
 class ListDestroyModelMixin(BulkOperationBaseMixin):
     def delete(self, request, *args, **kwargs):
         if self.is_object_operation():
-            return super(ListDestroyModelMixin, self).destroy(request, *args, **kwargs)
+            return super().destroy(request, *args, **kwargs)
         else:
             return self.destroy_bulk(request, *args, **kwargs)
 
@@ -60,7 +60,7 @@ class ListDestroyModelMixin(BulkOperationBaseMixin):
 class ListUpdateModelMixin(BulkOperationBaseMixin):
     def patch(self, request, *args, **kwargs):
         if self.is_object_operation():
-            return super(ListUpdateModelMixin, self).partial_update(request, *args, **kwargs)
+            return super().partial_update(request, *args, **kwargs)
         else:
             return self.partial_update_bulk(request, *args, **kwargs)
 
@@ -68,16 +68,19 @@ class ListUpdateModelMixin(BulkOperationBaseMixin):
         is_valid, errors = self.is_valid_bulk_operation()
         if is_valid:
             queryset = self.filter_queryset(self.get_queryset())
-            update_bulk_dict = self.get_update_bulk_dict(serializer=self.get_serializer_class()(), data=request.data)
-            self.pre_save_bulk(queryset, update_bulk_dict)  # todo: test and document me
+            update_bulk_dict = self.get_update_bulk_dict(
+                serializer=self.get_serializer_class()(), data=request.data)
+            # todo: test and document me
+            self.pre_save_bulk(queryset, update_bulk_dict)
             try:
                 queryset.update(**update_bulk_dict)
             except ValueError as e:
                 errors = {
-                    'detail': force_text(e)
+                    'detail': force_str(e)
                 }
                 return Response(errors, status=status.HTTP_400_BAD_REQUEST)
-            self.post_save_bulk(queryset, update_bulk_dict)  # todo: test and document me
+            # todo: test and document me
+            self.post_save_bulk(queryset, update_bulk_dict)
             return Response(status=status.HTTP_204_NO_CONTENT)
         else:
             return Response(errors, status=status.HTTP_400_BAD_REQUEST)
