@@ -1,10 +1,10 @@
-# -*- coding: utf-8 -*-
 from rest_framework.relations import HyperlinkedRelatedField
 
 
 class ResourceUriField(HyperlinkedRelatedField):
     """
-    Represents a hyperlinking uri that points to the detail view for that object.
+    Represents a hyperlinking uri that points to the
+    detail view for that object.
 
     Example:
         class SurveySerializer(serializers.ModelSerializer):
@@ -25,4 +25,4 @@ class ResourceUriField(HyperlinkedRelatedField):
 
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('source', '*')
-        super(ResourceUriField, self).__init__(*args, **kwargs)
\ No newline at end of file
+        super().__init__(*args, **kwargs)
