@@ -1,7 +1,5 @@
-# -*- coding: utf-8 -*-
-
 from django.test import TestCase, override_settings
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 
 
 @override_settings(ROOT_URLCONF='tests_app.tests.functional.cache.decorators.urls')
@@ -9,7 +7,7 @@ class TestCacheResponseFunctionally(TestCase):
 
     def test_should_return_response(self):
         resp = self.client.get('/hello/')
-        self.assertEqual(force_text(resp.content), '"Hello world"')
+        self.assertEqual(force_str(resp.content), '"Hello world"')
 
     def test_should_return_same_response_if_cached(self):
         resp_1 = self.client.get('/hello/')
