@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import django_filters
 from rest_framework import viewsets
 
@@ -10,4 +9,4 @@ class UserModelViewSet(viewsets.ModelViewSet):
     queryset = UserModel.objects.all()
     serializer_class = UserModelSerializer
     filter_backends = (django_filters.rest_framework.DjangoFilterBackend,)
-    filter_fields = ('property',)
+    filterset_fields = ('property',)
