@@ -4,6 +4,6 @@ from .views import CommentViewSet, CommentViewSetWithPermissions
 
 
 viewset_router = routers.DefaultRouter()
-viewset_router.register('comments', CommentViewSet)
-viewset_router.register('comments-with-permissions', CommentViewSetWithPermissions)
+viewset_router.register('comments', CommentViewSet, basename='alt1')
+viewset_router.register('comments-with-permissions', CommentViewSetWithPermissions, basename='alt2')
 urlpatterns = viewset_router.urls
