@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import django_filters
 from rest_framework import viewsets, serializers
 from rest_framework import filters
@@ -26,7 +25,7 @@ class CommentViewSet(ListDestroyModelMixin, viewsets.ModelViewSet):
     queryset = Comment.objects.all()
     serializer_class = CommentSerializer
     filter_backends = (django_filters.rest_framework.DjangoFilterBackend,)
-    filter_class = CommentFilter
+    filterset_class = CommentFilter
 
 
 class CommentViewSetWithPermissions(CommentViewSet):
