@@ -9,11 +9,12 @@ from .views import (
 
 
 viewset_router = routers.DefaultRouter()
-viewset_router.register('comments', CommentViewSet)
-viewset_router.register('comments-permission-filter-backend', CommentViewSetPermissionFilterBackend)
-viewset_router.register('comments-without-hiding-forbidden-objects', CommentViewSetWithoutHidingForbiddenObjects)
+viewset_router.register('comments', CommentViewSet, basename='alt1')
+viewset_router.register('comments-permission-filter-backend', CommentViewSetPermissionFilterBackend, basename='alt2')
+viewset_router.register('comments-without-hiding-forbidden-objects', CommentViewSetWithoutHidingForbiddenObjects, basename='alt3')
 viewset_router.register(
     'comments-without-hiding-forbidden-objects-permission-filter-backend',
-    CommentViewSetWithoutHidingForbiddenObjectsPermissionFilterBackend
+    CommentViewSetWithoutHidingForbiddenObjectsPermissionFilterBackend,
+    basename='alt4'
 )
 urlpatterns = viewset_router.urls
