@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
 from rest_framework import viewsets
-from rest_framework.decorators import detail_route, list_route
+from rest_framework.decorators import action
 
 from .models import RouterTestModel
 
@@ -8,10 +7,10 @@ from .models import RouterTestModel
 class RouterViewSet(viewsets.ModelViewSet):
     queryset = RouterTestModel.objects.all()
 
-    @detail_route()
+    @action(detail=True)
     def detail_controller(self):
         pass
 
-    @list_route()
+    @action(detail=False)
     def list_controller(self):
         pass
