@@ -1,6 +1,9 @@
 from django.core.cache import caches
 from django.test import TestCase
-from mock import Mock, patch
+try:
+    from unittest.mock import Mock, patch
+except ImportError:
+    from mock import Mock, patch
 from rest_framework import views
 from rest_framework.response import Response
 
@@ -17,6 +20,7 @@ class CacheResponseTest(TestCase):
         super().setUp()
         self.request = factory.get('')
         self.cache = caches[extensions_api_settings.DEFAULT_USE_CACHE]
+        self.cache.clear()
 
     def test_should_return_response_if_it_is_not_in_cache(self):
         class TestView(views.APIView):
